# csvtotrello

💻 Basic Python script to bulk import CSV backlog into Trello

## 🛠 Install
`pip install csvtotrello`

## 🎉 Get started
- Get your trello API key from [here](https://trello.com/app-key).
- Get your board id.
- `csvtotrello <trello_api_key> <trello_api_token> <board_id> <file_path_to_csv>`
